"""
About:
------
The sina_morph_analyze tool is designed to provide morphological analysis for Arabic text using the SinaTools' `analyze` utility. Users can specify the language and desired analysis task (e.g., lemmatization, part-of-speech tagging, or a full morphological analysis).

Usage:
------
Below is the usage information that can be generated by running sina_morph_analyze --help.

.. code-block:: none

    sina_morph_analyze --text=TEXT [OPTIONS]
    sina_morph_analyze --file=FILE [OPTIONS]

Options:
--------

.. code-block:: none

  --text TEXT
        The text that needs to be morphologically analyzed. 

  --file FILE
        File containing the text to be morphologically analyzed

  --language LANGUAGE [default=MSA]
        Specifies the language for the analysis. The default is MSA (Modern Standard Arabic). 
        Use other codes as appropriate for your requirements.

  --task TASK [default=full]
        Determines the specific type of morphological analysis to be performed. Available options are:
          - lemmatizer: Provides lemmatization results.
          - pos: Provides part-of-speech tagging.
          - full: Provides a comprehensive morphological analysis.
        The default is a full morphological analysis.

Examples:
---------

.. code-block:: none

  sina_morph_analyze --text "Your Arabic text here" --language MSA --task full
  sina_morph_analyze --text "Your Arabic text here" --task lemmatizer
  sina_morph_analyze --file "path/to/your/file.txt" --language MSA --task full
  sina_morph_analyze --file "path/to/your/file.txt" --task lemmatizer

Note:
-----

.. code-block:: none
  
  - Ensure that the text input is appropriately encoded in UTF-8 or compatible formats.
  - The quality and accuracy of the analysis depend on the underlying capabilities of the SinaTools' `analyze` utility.
  - The analysis can be influenced by the choice of language. Ensure you are using the correct language setting.

"""

import argparse
from nlptools.morphology.morph_analyzer import analyze
from nlptools.utils.readfile import read_file

def main():
    parser = argparse.ArgumentParser(description='Morphological Analysis using SinaTools')
    
    # Adding arguments for the text, file, language, and task
    parser.add_argument('--text', type=str, help='Text to be morphologically analyzed')
    parser.add_argument('--file', type=str, help='File containing the text to be morphologically analyzed')
    parser.add_argument('--language', type=str, default='MSA', help='Language for analysis (default: MSA)')
    parser.add_argument('--task', type=str, default='full', choices=['lemmatizer', 'pos', 'full'], 
                        help='Task for the result filter [lemmatizer, pos, full] (default: full)')

    args = parser.parse_args()

    if args.text is None and args.file is None:
        print("Error: Either --text or --file argument must be provided.")
        return

    # Get the input either from the --text argument or from the file specified in the --file argument
    input_text = args.text if args.text else " ".join(read_file(args.file))

    # Perform morphological analysis
    results = analyze(input_text, args.language, args.task)
    
    # Print the results
    for result in results:
        print(result)

if __name__ == '__main__':
    main()
#sina_morph_analyze --text "Your Arabic text here" --language MSA --task full
#sina_morph_analyze --file "path/to/your/file.txt" --language MSA --task full
